@@ -270,7 +270,7 @@ def engine_NComponent(sim):
     pf_comp_y = 8*sim.y_e*T*((2*a2_b2*psiy3 - 2*ab2*psix3)/vertex_centered_mgphi2 - vertex_averaged_gphi[1]*(psix3*vertex_centered_gpsi[0] + psiy3*vertex_centered_gpsi[1])/(vertex_centered_mgphi2*vertex_centered_mgphi2))
     pf_comp_y = (np.roll(pf_comp_y, -1, 1) - pf_comp_y)/dx
     pf_comp_y = (np.roll(pf_comp_y, -1, 0) + pf_comp_y)/2.
-    deltaphi = M_phi*(sim.ebar*sim.ebar*((1-3*sim.y_e)*divTgradphi + pf_comp_x + pf_comp_y)-30*g*(G_S-G_L)/sim.v_m-well-4*sim.H*T*phi*rgqs_0*1574.)
+    deltaphi = M_phi*(sim.ebar*sim.ebar*((1-3*sim.y_e)*divTgradphi + pf_comp_x + pf_comp_y)-30*g*(G_S-G_L)/sim.v_m-well-4*sim.H*T*phi*rgqs_0)
 
     #old noise from Warren1995:
     #randArray = 2*np.random.random_sample(shape)-1
@@ -300,8 +300,8 @@ def engine_NComponent(sim):
     cc_t4_temp = (t4_temp + np.roll(t4_temp, -1, 0))/2.
     cc_t4_temp = (cc_t4_temp + np.roll(cc_t4_temp, -1, 1))/2.
     
-    t1 = (gaq1)*1574. + cc_t1_temp
-    t4 = (gaq4)*1574. + cc_t4_temp
+    t1 = gaq1 + cc_t1_temp
+    t4 = gaq4 + cc_t4_temp
 
     #add Dorr2010 term to quaternion field
     t1 += sim.eqbar*sim.eqbar*lq1
